==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/Save/ts/Save_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Save</name>
    <message>
        <location filename="../Save.js" line="+77"/>
        <source>Overwrite File?</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Substitua o Arquivo?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>O arquivo &apos;%1&apos; já existe. Você deseja substituí-lo?</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Todas as cores personalizadas serão aproximadas para a cor fixa mais próxima.</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>File Format Version Not Recommended</source>
        <translation>Versão de Formato de Arquivo Não Recomendada</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file format version you are using is not recommended: &apos;%1&apos;.</source>
        <translation>A versão de formato de arquivo que você está usando não é recomendada: &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All black entities and layers will be saved as white.</source>
        <translation>Todas as entidades e camadas negras serão salvas como brancas.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Proceed?</source>
        <translation>Proceder?</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Saved drawing:</source>
        <translation>Desenho gravado:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color. Proceed?</source>
        <translation type="obsolete">Todas as cores personalizadas serão &apos;arredondado&apos; para a cor mais próxima fixo. Proceder?</translation>
    </message>
    <message>
        <location line="-29"/>
        <source>Saving...</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
A guardar...</translatorcomment>
        <translation>Gravando...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saving to file format version &apos;%1&apos;.</source>
        <translation>Gravando em arquivo formato versão &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black entities and layers are saved as white.</source>
        <translation>Entidades e camadas negras são salvas como brancas.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom colors are &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>As cores personalizadas são aproximadas para a cor fixa mais próxima.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>File %1 has not been saved.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>O arquivo &apos;%1&apos; não foi gravado.</translation>
    </message>
    <message>
        <source>Saved drawing: %1</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Desenho salvo: %1</translatorcomment>
        <translation type="obsolete">Desenho guardado: %1</translation>
    </message>
    <message>
        <location filename="../SaveInit.js" line="+2"/>
        <source>&amp;Save</source>
        <translatorcomment>--exact match--
--file: qt_pt.ts--
&amp;Gravar</translatorcomment>
        <translation>&amp;Grave</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/Save/ts/Save_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>Save</name>
    <message>
        <location filename="../Save.js" line="+78"/>
        <source>Overwrite File?</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Substitua o Arquivo?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>O arquivo &apos;%1&apos; já existe. Você deseja substituí-lo?</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Todas as cores personalizadas serão aproximadas para a cor fixa mais próxima.</translation>
    </message>
    <message>
        <location line="-4"/>
        <source>File Format Version Not Recommended</source>
        <translation>Versão de Formato de Arquivo Não Recomendada</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file format version you are using is not recommended: &apos;%1&apos;.</source>
        <translation>A versão de formato de arquivo que você está usando não é recomendada: &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom properties will not be saved.</source>
        <translation>As propriedades personalizadas não serão salvas.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All black entities and layers will be saved as white.</source>
        <translation>Todas as entidades e camadas negras serão salvas como brancas.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Proceed?</source>
        <translation>Proceder?</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Saved drawing:</source>
        <translation>Desenho gravado:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color. Proceed?</source>
        <translation type="obsolete">Todas as cores personalizadas serão &apos;arredondado&apos; para a cor mais próxima fixo. Proceder?</translation>
    </message>
    <message>
        <location line="-32"/>
        <source>Saving...</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
A guardar...</translatorcomment>
        <translation>Gravando...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saving to file format version &apos;%1&apos;.</source>
        <translation>Gravando em arquivo formato versão &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black entities and layers are saved as white.</source>
        <translation>Entidades e camadas negras são salvas como brancas.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom colors are &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>As cores personalizadas são aproximadas para a cor fixa mais próxima.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>File %1 has not been saved.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>O arquivo &apos;%1&apos; não foi gravado.</translation>
    </message>
    <message>
        <source>Saved drawing: %1</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Desenho salvo: %1</translatorcomment>
        <translation type="obsolete">Desenho guardado: %1</translation>
    </message>
    <message>
        <location filename="../SaveInit.js" line="+2"/>
        <source>&amp;Save</source>
        <translatorcomment>--exact match--
--file: qt_pt.ts--
&amp;Gravar</translatorcomment>
        <translation>&amp;Grave</translation>
    </message>
</context>
</TS>
